smartcard.ClassLoader

# ``smartcard`.`ClassLoader``

module documentation

ClassLoader allows you to load modules from packages without hard-coding their class names in code; instead, they might be specified in a configuration file, as command-line parameters, or within an interface.

Source: Robert Brewer at the Python Cookbook: http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/223972

License: PSF license (http://docs.python.org/license.html).

Function | `get_class` | Load a module and retrieve a class (NOT an instance).
Function | `get_func` | Retrieve a function object from a full dotted-package name.
Function | `get_mod` | Import a module.

def get_class(fullClassName, parentClass=None):

Load a module and retrieve a class (NOT an instance).

If the parentClass is supplied, className must be of parentClass or a subclass of parentClass (or None is returned).

def get_func(fullFuncName):

Retrieve a function object from a full dotted-package name.

def get_mod(modulePath):

Import a module.